summaryrefslogtreecommitdiffstats
path: root/Lib/importlib
diff options
context:
space:
mode:
authorSerhiy Storchaka <storchaka@gmail.com>2016-06-12 14:36:24 (GMT)
committerSerhiy Storchaka <storchaka@gmail.com>2016-06-12 14:36:24 (GMT)
commit64204de04cb24bb70b1cf011d812d35c8ff40337 (patch)
tree08fd1decdb9c3d56d2b863863d4d2dd5ff074b7e /Lib/importlib
parent5697c4b6419e5a90a59e616e4509a6fff7ebf1a8 (diff)
downloadcpython-64204de04cb24bb70b1cf011d812d35c8ff40337.zip
cpython-64204de04cb24bb70b1cf011d812d35c8ff40337.tar.gz
cpython-64204de04cb24bb70b1cf011d812d35c8ff40337.tar.bz2
Issue #27095: Simplified MAKE_FUNCTION and removed MAKE_CLOSURE opcodes.
Patch by Demur Rumed.
Diffstat (limited to 'Lib/importlib')
-rw-r--r--Lib/importlib/_bootstrap_external.py8
1 files changed, 5 insertions, 3 deletions
diff --git a/Lib/importlib/_bootstrap_external.py b/Lib/importlib/_bootstrap_external.py
index 6fe3643..30e8330 100644
--- a/Lib/importlib/_bootstrap_external.py
+++ b/Lib/importlib/_bootstrap_external.py
@@ -222,8 +222,10 @@ _code_type = type(_write_atomic.__code__)
# Python 3.5.2 3351 (fix BUILD_MAP_UNPACK_WITH_CALL opcode #27286)
# Python 3.6a0 3360 (add FORMAT_VALUE opcode #25483
# Python 3.6a0 3361 (lineno delta of code.co_lnotab becomes signed)
# Python 3.6a0 3370 (16 bit wordcode)
# Python 3.6a0 3371 (add BUILD_CONST_KEY_MAP opcode #27140)
#
# MAGIC must change whenever the bytecode emitted by the compiler may no
# longer be understood by older implementations of the eval loop (usually
@@ -232,7 +234,7 @@ _code_type = type(_write_atomic.__code__)
# Whenever MAGIC_NUMBER is changed, the ranges in the magic_values array
# in PC/launcher.c must also be updated.
-MAGIC_NUMBER = (3371).to_bytes(2, 'little') + b'\r\n'
+MAGIC_NUMBER = (3372).to_bytes(2, 'little') + b'\r\n'
_RAW_MAGIC_NUMBER = int.from_bytes(MAGIC_NUMBER, 'little') # For import.c
_PYCACHE = '__pycache__'
@@ -222,8 +222,10 @@ _code_type = type(_write_atomic.__code__)
# Python 3.6a0 3360 (add FORMAT_VALUE opcode #25483
# Python 3.6a0 3361 (lineno delta of code.co_lnotab becomes signed)
-# Python 3.6a0 3370 (16 bit wordcode)
-# Python 3.6a0 3371 (add BUILD_CONST_KEY_MAP opcode #27140)
+# Python 3.6a1 3370 (16 bit wordcode)
+# Python 3.6a1 3371 (add BUILD_CONST_KEY_MAP opcode #27140)
+# Python 3.6a1 3372 (MAKE_FUNCTION simplification, remove MAKE_CLOSURE
+ #27095)
#
# MAGIC must change whenever the bytecode emitted by the compiler may no